@@ -40,14 +40,35 @@ class IObjectHistory(Interface):
         Returns the unpicked state, not an actual persistent object.
         """
 
+    def loadStatePickle(tid=None):
+        """Load and return the object's historical state at or before tid.
+
+        Returns the picked state as a string.
+        """
+
     def rollback(tid):
         """Roll back object state to what it was at or before tid."""
 
 
+class IDatabaseHistory(Interface):
+    """History of the entire database.
+
+    Adapt a connection object to IObjectHistory.
+    """
+
+    def __iter__(n):
+        """Return an iterator over the history record.
+
+        Records are ordered by age, from oldest (index 0) to newest.
+
+        Each record provides ZODB.interfaces.an IStorageTransactionInformation.
+        """
+
+
 class IValueRenderer(Interface):
     """Renderer of attribute values."""
 
-    def render(tid=None):
+    def render(tid=None, can_link=True):
         """Render object value to HTML.
 
         Hyperlinks to other persistent objects will be limited to versions
